Module asar

Module asar 

Structs

AsarArchive
An ASAR archive that can be read from or written to disk.
CreateOptions
Options for creating an ASAR archive.

Functions

create_package
Create a new ASAR archive from a directory using default options.
create_package_from_files
Create an ASAR archive from a pre-crawled list of files.
create_package_with_options
Create a new ASAR archive from a directory with custom options.
extract_all
Extract all files from the archive to a destination directory.
extract_file
Extract a single file’s contents from the archive.
get_raw_header
Read the raw archive header without caching the filesystem.
list_package
List all files in the archive.
stat_file
Get metadata for a file in the archive.