Structs
- Asar
Archive - An ASAR archive that can be read from or written to disk.
- Create
Options - Options for creating an ASAR archive.
Functions
- create_
package - Create a new ASAR archive from a directory using default options.
- create_
package_ from_ files - Create an ASAR archive from a pre-crawled list of files.
- create_
package_ with_ options - Create a new ASAR archive from a directory with custom options.
- extract_
all - Extract all files from the archive to a destination directory.
- extract_
file - Extract a single file’s contents from the archive.
- get_
raw_ header - Read the raw archive header without caching the filesystem.
- list_
package - List all files in the archive.
- stat_
file - Get metadata for a file in the archive.